@@ -1,5 +1,5 @@
 /*
-$Id: dsmcc_misc.h,v 1.6 2004/02/17 23:54:12 rasc Exp $
+$Id: dsmcc_misc.h,v 1.10 2006/03/06 20:25:37 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: dsmcc_misc.h,v 1.6 2004/02/17 23:54:12 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 */
@@ -37,7 +37,7 @@ typedef struct _DSMCC_MSG_HEADER {
 
 
 
-int   dsmcc_pto_descriptor_loop (u_char *name, u_char *b);
+int   dsmcc_pto_descriptor_loop (char *name, u_char *b);
 int   dsmcc_CompatibilityDescriptor(u_char *b);
 
 int   dsmcc_MessageHeader (int v, u_char *b, int len, DSMCC_MSG_HD *dmh);
@@ -49,6 +49,7 @@ u_long dsmcc_print_transactionID_32 (int v, u_char *b);
 
 int   dsmcc_carousel_NSAP_address_B20 (int v, const char *s, u_char *b);
 int   dsmcc_CarouselDescriptor_Loop (const char *s, u_char *b, int len);
+int   dsmcc_DVB_service_location (int v, u_char *b);
 
 
 #endif
