@@ -1,5 +1,5 @@
 /*
-$Id: dsmcc_int_unt_descriptor.h,v 1.12 2005/01/17 19:41:22 rasc Exp $ 
+$Id: dsmcc_int_unt_descriptor.h,v 1.14 2006/03/06 00:04:52 rasc Exp $ 
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: dsmcc_int_unt_descriptor.h,v 1.12 2005/01/17 19:41:22 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
  -- Private TAG Space  DSM-CC   INT, UNT, ...
@@ -16,6 +16,15 @@ $Id: dsmcc_int_unt_descriptor.h,v 1.12 2005/01/17 19:41:22 rasc Exp $
 
 
 $Log: dsmcc_int_unt_descriptor.h,v $
+Revision 1.14  2006/03/06 00:04:52  rasc
+More DSM-CC stuff: BIOP::FileMessage, BIOP::DirectoryMessage,
+BIOP::Stream::BIOP::StreamEvent, BIOP::ServiceGateway, DSM-TAPs, etc.
+this is a preparation for a patch sent in by Richard Case (DSMCC-Save).
+Attention: Code is still untested and may considered to be buggy (some teststreams are needed)...
+
+Revision 1.13  2006/01/02 18:23:58  rasc
+just update copyright and prepare for a new public tar ball
+
 Revision 1.12  2005/01/17 19:41:22  rasc
 Bugfix: data broadcast descriptor (tnx to Sergio SAGLIOCCO, SecureLAB)
 
@@ -61,7 +70,7 @@ more PES stuff, DSM descriptors, testdata
 
 
 #ifndef __DSM_INT_UNT_DESCRIPTOR_H
-#define __DSM_INT_UNT_DESCRIPTOR_H 1
+#define __DSM_INT_UNT_DESCRIPTOR_H 
 
 
 int  descriptorDSMCC_INT_UNT (u_char *b);
