@@ -1,5 +1,5 @@
 /*
-$Id: dvb_descriptor.h,v 1.12 2005/01/17 19:41:22 rasc Exp $ 
+$Id: dvb_descriptor.h,v 1.16 2006/03/06 00:04:52 rasc Exp $ 
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: dvb_descriptor.h,v 1.12 2005/01/17 19:41:22 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
  -- DVB Descriptors  ETSI 300 468
@@ -15,6 +15,23 @@ $Id: dvb_descriptor.h,v 1.12 2005/01/17 19:41:22 rasc Exp $
 
 
 $Log: dvb_descriptor.h,v $
+Revision 1.16  2006/03/06 00:04:52  rasc
+More DSM-CC stuff: BIOP::FileMessage, BIOP::DirectoryMessage,
+BIOP::Stream::BIOP::StreamEvent, BIOP::ServiceGateway, DSM-TAPs, etc.
+this is a preparation for a patch sent in by Richard Case (DSMCC-Save).
+Attention: Code is still untested and may considered to be buggy (some teststreams are needed)...
+
+Revision 1.15  2006/01/02 18:23:58  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.14  2005/12/22 16:21:50  rasc
+Update and new descriptors EN 300 468 v1.7.1
+
+Revision 1.13  2005/11/08 23:15:24  rasc
+ - New: DVB-S2 Descriptor and DVB-S2 changes (tnx to Axel Katzur)
+ - Bugfix: PES packet stuffing
+ - New:  PS/PES read redesign and some code changes
+
 Revision 1.12  2005/01/17 19:41:22  rasc
 Bugfix: data broadcast descriptor (tnx to Sergio SAGLIOCCO, SecureLAB)
 
@@ -67,7 +84,7 @@ trying to include DSM-CC, Well someone a ISO13818-6 and latest version of ISO 18
 
 
 #ifndef _DVB_DESCRIPTOR_H
-#define _DVB_DESCRIPTOR_H 1
+#define _DVB_DESCRIPTOR_H 
 
 
 int   descriptorDVB (u_char *b);
@@ -113,7 +130,7 @@ void  descriptorDVB_FrequencyList (u_char *b);
 void  descriptorDVB_ShortSmoothingBuffer(u_char *b);
 void  descriptorDVB_PartialTransportStream(u_char *b);
 void  descriptorDVB_DataBroadcast (u_char *b);
-void  descriptorDVB_CASystem(u_char *b);
+void  descriptorDVB_Scrambling(u_char *b);
 void  descriptorDVB_DataBroadcastID(u_char *b);
 void  descriptorDVB_TransportStream(u_char *b);
 void  descriptorDVB_DSNG(u_char *b);
@@ -135,6 +152,12 @@ void  descriptorDVB_ContentIdentifier(u_char *b);
 		 // EN 301 192 v1.4.1  MPE_FEC
 void  descriptorDVB_TimesliceFecIdentifier(u_char *b);
 void  descriptorDVB_ECM_RepetitionRate(u_char *b);
+		 // EN 300 468 v1.7.1
+void  descriptorDVB_S2SatelliteDeliverySystem(u_char *b);
+void  descriptorDVB_Enhanced_AC3(u_char *b);
+void  descriptorDVB_DTS_Audio (u_char *b);
+void  descriptorDVB_AAC (u_char *b);
+void  descriptorDVB_Extension (u_char *b);
 
 
 
