@@ -1,5 +1,5 @@
 /*
-$Id: mpeg_descriptor.c,v 1.26 2004/11/03 21:00:52 rasc Exp $
+$Id: mpeg_descriptor.c,v 1.29 2006/02/12 23:17:11 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: mpeg_descriptor.c,v 1.26 2004/11/03 21:00:52 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 
@@ -18,6 +18,15 @@ $Id: mpeg_descriptor.c,v 1.26 2004/11/03 21:00:52 rasc Exp $
 
 
 $Log: mpeg_descriptor.c,v $
+Revision 1.29  2006/02/12 23:17:11  rasc
+TS 101 191 MIP - Mega-Frame Initialization Packet for DVB-T/H  (TS Pid 0x15)
+
+Revision 1.28  2006/01/02 18:23:58  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.27  2005/11/10 23:34:37  rasc
+Some H.222.1 AMD 4+5 update
+
 Revision 1.26  2004/11/03 21:00:52  rasc
  - New: "premiere.de" private tables and descriptors (tnx to Peter.Pavlov, Premiere)
  - New: cmd option "-privateprovider <provider name>"
@@ -153,26 +162,26 @@ int  descriptorMPEG  (u_char *b)
 
 {
  int len;
- int id;
+ int tag;
 
 
-  id  =  (int) b[0];
-  len = ((int) b[1]) + 2;
 
   out_NL (4);
-  out_S2B_NL (4,"MPEG-DescriptorTag: ",id, dvbstrMPEGDescriptorTAG(id));
-  out_SB_NL  (5,"Descriptor_length: ",b[1]);
+  tag = outBit_S2x_NL (4,"MPEG-DescriptorTag: ",	b,   0,  8,
+		(char *(*)(u_long))dvbstrMPEGDescriptorTAG); 
+  len = outBit_Sx_NL  (4,"descriptor_length: ",	 	b,   8,  8);
+
 
   // empty ??
-  len = ((int)b[1]) + 2;
-  if (b[1] == 0)
-	 return len;
+  if (len == 0) return len;
 
   // print hex buf of descriptor
-  printhex_buf (9, b,len);
+  printhex_buf (9, b,len+2);
 
 
-  switch (b[0]) {
+
+  switch (tag) {
+
      case 0x02:  descriptorMPEG_VideoStream  (b);  break;
      case 0x03:  descriptorMPEG_AudioStream  (b);  break;
      case 0x04:  descriptorMPEG_Hierarchy  (b);  break;
@@ -213,7 +222,6 @@ int  descriptorMPEG  (u_char *b)
      case 0x21:  descriptorMPEG_MuxCode (b);  break; 
      case 0x22:  descriptorMPEG_FMXBufferSize (b);  break; 
      case 0x23:  descriptorMPEG_MultiplexBuffer (b);  break; 
-     // case 0x24:  descriptorMPEG_FlexMuxTiming (b);  break;  // collision with content_labeling desc.  H.222.0 (obsolete??)
      case 0x24:  descriptorMPEG_ContentLabeling(b);  break;
 
      /* TV ANYTIME, TS 102 323 */
@@ -226,17 +234,20 @@ int  descriptorMPEG  (u_char *b)
      case 0x29:  descriptorMPEG_IPMP (b);  break; 
      case 0x2A:  descriptorMPEG_AVC_timing_and_HRD (b);  break; 
 
+     /* H.222.0 Corr 4 */
+     case 0x2B:  descriptorMPEG_MPEG2_AAC_audio (b);  break;
+     case 0x2C:  descriptorMPEG_FlexMuxTiming (b);  break;
+
      default: 
-	if (b[0] < 0x80) {
+	if (tag < 0x80) {
 	   out_nl (0,"  ----> ERROR: unimplemented descriptor (mpeg context), Report!");
 	}
-	// descriptor_any (b);
 	descriptor_PRIVATE (b,MPEG);
 	break;
   } 
 
 
-  return len;   // (descriptor total length)
+  return len+2;   // (descriptor total length)
 }
 
 
@@ -1606,27 +1617,6 @@ void descriptorMPEG_MultiplexBuffer (u_char *b)
 
 
 
-// ---- collision with old H.222.0 draft, obsolete??
-
-// /*
-//   0x24   Flex-Mux-Timing descriptor
-//   ITU-T H.222.0-I-Cor1 
-// */
-// 
-// void descriptorMPEG_FlexMuxTiming (u_char *b)
-// 
-// {
-//   // d.descriptor_tag		 = b[0];
-//   // d.descriptor_length       	 = b[1];
-// 
-// 
-//  outBit_Sx_NL   (4,"FCR_ES_ID: ",  	b,16,16);
-//  outBit_S2Tx_NL (4,"FCRResolution: ",  	b,32,32,"(cycles/s)");
-//  outBit_Sx_NL   (4,"FCRLength: ",  	b,64, 8);
-//  outBit_Sx_NL   (4,"FCRRateLength: ",  	b,72, 8);
-// 
-// }
-
 
 
 
@@ -1699,7 +1689,7 @@ void descriptorMPEG_ContentLabeling (u_char *b)
   	outBit_Sx_NL   (6,"reserved: ",  	b, 40,  7);
 	ll = getBits48 (b, 0,  47, 33);
 	out_S2LL_NL(4,"metadata_time_base_value: ",ll,"90kHz units");
-	// -- following is wrong, because of different unit measuring
+	// -- following is wrong, because of different unit measuring  $$$ TODO: check
 	// out (4,"metadata_time_base_value: ");
 	// print_timebase90kHz (4, ll);
 	// out_NL (4);
@@ -1841,6 +1831,8 @@ void descriptorMPEG_IPMP (u_char *b)
 
 
 
+
+
 /*
   0x2A  AVC_timing_and_HRD descriptor
   H.222.0 AMD 3
@@ -1864,3 +1856,47 @@ void descriptorMPEG_AVC_timing_and_HRD (u_char *b)
 
 
 
+/*
+  0x2B  MPEG-2_AAC_audio descriptor
+  H.222.0 AMD 4
+  ISO/IEC 13818-1:2000/Amd.5:2005 (E)
+*/
+
+void descriptorMPEG_MPEG2_AAC_audio (u_char *b)
+{
+  // d.descriptor_tag		 = b[0];
+  // d.descriptor_length       	 = b[1];
+
+  outBit_Sx_NL   (4,"MPEG-2_AAC_profile: ",  			b, 16,  8);
+	// $$$ TODO:  ISO/IEC 13818-7:2004 subclause 7.1 Table 31.
+
+  outBit_Sx_NL   (4,"MPEG-2_AAC_channel_configuration: ",  	b, 24,  8);
+	// $$$ TODO:  ISO/IEC 13818-7:2004 subclause 8.9 Table 42
+
+  outBit_Sx_NL   (4,"MPEG-2_AAC_additional_information: ",  	b, 32,  8);
+  	// $$$ TODO:  ISO/IEC 13818-7:2004 is embedded in the AAC bitstream according to Table Amd.5-2.
+
+}
+
+
+
+
+/*
+   0x2C   Flex-Mux-Timing descriptor
+   ITU-T H.222.0-I-Cor1 
+*/
+ 
+void descriptorMPEG_FlexMuxTiming (u_char *b)
+{
+  // d.descriptor_tag		 = b[0];
+  // d.descriptor_length       	 = b[1];
+
+
+  outBit_Sx_NL   (4,"FCR_ES_ID: ",  	b,16,16);
+  outBit_S2Tx_NL (4,"FCRResolution: ", 	b,32,32,"(cycles/s)");
+  outBit_Sx_NL   (4,"FCRLength: ",  	b,64, 8);
+  outBit_Sx_NL   (4,"FCRRateLength: ", 	b,72, 8);
+ 
+}
+
+
