@@ -1,5 +1,5 @@
 /*
-$Id: dmx_sect.c,v 1.30 2005/08/02 22:57:46 rasc Exp $
+$Id: dmx_sect.c,v 1.34 2006/01/02 18:23:58 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: dmx_sect.c,v 1.30 2005/08/02 22:57:46 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
  --  Sections Streams
@@ -18,6 +18,21 @@ $Id: dmx_sect.c,v 1.30 2005/08/02 22:57:46 rasc Exp $
 
 
 $Log: dmx_sect.c,v $
+Revision 1.34  2006/01/02 18:23:58  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.33  2005/10/20 22:25:06  rasc
+ - Bugfix: tssubdecode check for PUSI and SI pointer offset
+   still losing packets, when multiple sections in one TS packet.
+ - Changed: some Code rewrite
+ - Changed: obsolete option -nosync, do always packet sync
+
+Revision 1.32  2005/09/06 23:32:03  rasc
+no message
+
+Revision 1.31  2005/09/06 23:13:51  rasc
+catch OS signals (kill ...) for smooth program termination
+
 Revision 1.30  2005/08/02 22:57:46  rasc
 Option -N, rewrite offline filters (TS & Section)
 
@@ -128,11 +143,11 @@ dvbsnoop v0.7  -- Commit to CVS
 #include "dvbsnoop.h"
 #include "misc/cmdline.h"
 #include "misc/output.h"
-#include "misc/hexprint.h"
-#include "misc/print_header.h"
 #include "misc/pid_mem.h"
+#include "misc/sig_abort.h"
 
 #include "sections/sectables.h"
+
 #include "dvb_api.h"
 #include "file_io.h"
 #include "dmx_error.h"
@@ -172,7 +187,7 @@ int  doReadSECT (OPTION *opt)
    if (opt->spider_pid) {
    	u_int  pid;
 
-	while (1) {
+	while ( !isSigAbort() ) {
 		pid = get_UnusedPidFromMem ();
 		if (pid == INVALID_PID) break;
 
@@ -213,7 +228,7 @@ static int  doReadSECT_2 (OPTION *opt)
 
   if (opt->inpPidFile) {
   	f        = opt->inpPidFile;
-  	openMode = O_RDONLY | O_LARGEFILE;
+  	openMode = O_RDONLY | O_LARGEFILE | O_BINARY;
         dmxMode  = 0;
   } else {
   	f        = opt->devDemux;
@@ -289,7 +304,7 @@ static int  doReadSECT_2 (OPTION *opt)
 
   count = 0;
   filtered_count = 0;
-  while (1) {
+  while ( !isSigAbort() ) {
     long   n;
     int    filter_match = 1;
 
@@ -350,24 +365,9 @@ static int  doReadSECT_2 (OPTION *opt)
 
 	} else {
 
-	       indent (0);
-	       print_packet_header (opt, "SECT", opt->pid, count, n, 0);
+	       processSI_packet (opt->pid, count, buf, n);
 
-
-	       if (opt->buffer_hexdump) {
-	           printhex_buf (0,buf, n);
-	           out_NL(0);
-	       }
-
-
-	       // decode protocol
-	       if (opt->printdecode) {
-	          decodeSections_buf (buf,n ,opt->pid);
-	          out_nl (3,"==========================================================");
-	          out_NL (3);
-	       }
-
-	} // bin_out
+	} 
 
     }  // filter_match: packet out
 
