@@ -1,17 +1,23 @@
 /*
-$Id: dmx_tspidbandwidth.c,v 1.11 2005/05/08 23:23:06 rasc Exp $
+$Id: dmx_tspidbandwidth.c,v 1.13 2006/01/02 18:23:59 rasc Exp $
 
 
  DVBSNOOP
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 
 
 $Log: dmx_tspidbandwidth.c,v $
+Revision 1.13  2006/01/02 18:23:59  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.12  2005/09/06 23:13:51  rasc
+catch OS signals (kill ...) for smooth program termination
+
 Revision 1.11  2005/05/08 23:23:06  rasc
 display bandwidth average at end of poll
 
@@ -74,6 +80,7 @@ new: bandwidth usage reporting for a PID
 #include "misc/cmdline.h"
 #include "misc/output.h"
 #include "misc/pkt_time.h"
+#include "misc/sig_abort.h"
 
 #include "dvb_api.h"
 #include "dmx_error.h"
@@ -181,7 +188,7 @@ int ts_pidbandwidth (OPTION *opt)
 	packets_total = 0;
   	packets_bad = 0;
 
-	while (1) {
+	while ( !isSigAbort() ) {
 		int b_len, b_start;
 
 		// -- we will poll the PID in 2 secs intervall
