@@ -1,5 +1,5 @@
 /*
-$Id: fe_signal.c,v 1.13 2005/08/13 00:06:56 rasc Exp $
+$Id: fe_signal.c,v 1.17 2006/01/02 18:23:59 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: fe_signal.c,v 1.13 2005/08/13 00:06:56 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de  (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de  (rasc)
 
 
  -- Signal Statistics  Current Frequency/Transponder
@@ -17,6 +17,18 @@ $Id: fe_signal.c,v 1.13 2005/08/13 00:06:56 rasc Exp $
 
 
 $Log: fe_signal.c,v $
+Revision 1.17  2006/01/02 18:23:59  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.16  2005/09/18 12:23:23  rasc
+no message
+
+Revision 1.15  2005/09/13 18:41:15  rasc
+... revert cygwin stuff
+
+Revision 1.14  2005/09/06 23:13:51  rasc
+catch OS signals (kill ...) for smooth program termination
+
 Revision 1.13  2005/08/13 00:06:56  rasc
 no message
 
@@ -77,6 +89,7 @@ simple frontend signal status query added "-s signal"
 #include "misc/cmdline.h"
 #include "misc/output.h"
 #include "misc/pkt_time.h"
+#include "misc/sig_abort.h"
 
 #include "dmx_error.h"
 #include "dvb_api.h"
@@ -145,7 +158,7 @@ int  do_SignalStrength (OPTION *opt)
 
 
   count = 0;
-  while (1) {
+  while ( !isSigAbort() ) {
 	int  err;
 	int  d_tim_ms;
 
@@ -174,7 +187,7 @@ int  do_SignalStrength (OPTION *opt)
 	if (has.strength)  out (1,"Sig: %u  ", s.strength & 0xFFFFL);
 	if (has.snr)	   out (2,"SNR: %u  ", s.snr & 0xFFFFL);
 	if (has.ber)	   out (3,"BER: %lu  ",s.ber);
-	if (has.ublocks)   out (4,"UBLK: %lu  ",s.ublocks);
+	if (has.ublocks)   out (4,"UBLK: %ld  ",s.ublocks);
 	if (has.status) {
 		out (4,"Stat: 0x%02x ",s.status);
 		out_status_detail (5,s.status);
