@@ -1,5 +1,5 @@
 /*
-$Id: cmdline.c,v 1.48 2005/08/12 23:02:35 rasc Exp $
+$Id: cmdline.c,v 1.51 2006/03/06 00:04:54 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: cmdline.c,v 1.48 2005/08/12 23:02:35 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 
@@ -15,6 +15,21 @@ $Id: cmdline.c,v 1.48 2005/08/12 23:02:35 rasc Exp $
 
 
 $Log: cmdline.c,v $
+Revision 1.51  2006/03/06 00:04:54  rasc
+More DSM-CC stuff: BIOP::FileMessage, BIOP::DirectoryMessage,
+BIOP::Stream::BIOP::StreamEvent, BIOP::ServiceGateway, DSM-TAPs, etc.
+this is a preparation for a patch sent in by Richard Case (DSMCC-Save).
+Attention: Code is still untested and may considered to be buggy (some teststreams are needed)...
+
+Revision 1.50  2005/12/29 02:43:38  rasc
+gcc fixes, man page update
+
+Revision 1.49  2005/10/20 22:25:07  rasc
+ - Bugfix: tssubdecode check for PUSI and SI pointer offset
+   still losing packets, when multiple sections in one TS packet.
+ - Changed: some Code rewrite
+ - Changed: obsolete option -nosync, do always packet sync
+
 Revision 1.48  2005/08/12 23:02:35  rasc
 New shortcut options: -adapter and -devnr to select dvb cards/adapters or device numbers on a card.
 This is a shortcut for -demux -dvr and -frontend...
@@ -254,12 +269,13 @@ int  cmdline_options (int argc, char **argv, OPTION *opt)
   opt->ts_raw_mode = 0;
   opt->rd_packet_count = 0;
   opt->dec_packet_count = 0;
-  opt->packet_header_sync = 1;
+  opt->packet_header_sync = 1;  // $$$ OBSOLETE!
   opt->packet_mode = SECT;
   opt->time_mode = FULL_TIME;
   opt->hide_copyright= 0;
   opt->help = 0;
   opt->privateProviderStr = (char *)NULL;  // decoding known private tables/descriptors, ProviderStr
+  opt->dsmcc_save = 0;
 
   opt->filterLen = 0;
   memset(opt->filter, 0, DMX_FILTER_SIZE);
@@ -287,8 +303,8 @@ int  cmdline_options (int argc, char **argv, OPTION *opt)
      else if (!strcmp (argv[i],"-nocrc")) opt->crc = 0;
      else if (!strcmp (argv[i],"-softcrc")) opt->soft_crc = 1;
      else if (!strcmp (argv[i],"-nosoftcrc")) opt->soft_crc = 0;
-     else if (!strcmp (argv[i],"-sync")) opt->packet_header_sync = 1;
-     else if (!strcmp (argv[i],"-nosync")) opt->packet_header_sync = 0;
+     else if (!strcmp (argv[i],"-sync")) opt->packet_header_sync = 1; 
+     else if (!strcmp (argv[i],"-nosync")) opt->packet_header_sync = 0;  // -- obsolete
      else if (!strcmp (argv[i],"-n")) opt->rd_packet_count = str2i(argv[++i]);
      else if (!strcmp (argv[i],"-N")) opt->dec_packet_count = str2i(argv[++i]);
      else if (!strcmp (argv[i],"-b")) opt->binary_out = 1;
@@ -308,6 +324,7 @@ int  cmdline_options (int argc, char **argv, OPTION *opt)
      else if (!strcmp (argv[i],"-privateprovider")) opt->privateProviderStr = argv[++i];
      else if (!strcmp (argv[i],"-tssubdecode")) opt->ts_subdecode = 1;
      else if (!strcmp (argv[i],"-allsections")) opt->rd_all_sections = 1;
+     else if (!strcmp (argv[i],"-dsmccsave")) opt->dsmcc_save = 1;
      else if (!strcmp (argv[i],"-f")) {
 	 opt->filterLen = str2barray(argv[++i], opt->filter, DMX_FILTER_SIZE);
      } else if (!strcmp (argv[i],"-m")) {
@@ -512,7 +529,7 @@ static void usage (void)
     printf("   -softcrc:     internal soft CRC check when reading 'sec' [-nosoftcrc]\n");
     printf("   -nosoftcrc:   no internal soft CRC check when reading 'sec' [-nosoftcrc]\n");
     printf("   -sync:        simple packet header sync when reading 'ts' or 'pes' [-snyc]\n");
-    printf("   -nosync:      no header sync when reading 'ts' or 'pes' [-snyc]\n");
+    printf("   -nosync:      (obsolete option) \n");
     printf("   -n count:     receive/read max. <count> packets (0=no limit) [-n 0]\n");
     printf("   -N count:     decode max. <count> packets (0=no limit) [-N 0]\n");
     printf("                 this will limit -n, e.g. when using soft filters.\n");
@@ -531,6 +548,9 @@ static void usage (void)
     printf("   -npd:         don't print decoded stream (= -pd 0) \n");
     printf("   -t[n|d|f]:    print timestamp (no, delta, full) [-tf] \n");
     printf("   -privateprovider id: set provider <id> string for decoding private tables and descriptors\n");
+// $$$ TODO
+//    printf("   -dsmccsave:   Save of Digital Storage Media Command and Control objects, section modes only\n");
+//    printf("                 (currently only processing of BIOP Files and Directories is supported)\n");
     printf("   -hideproginfo: hide copyright and program info header at program start\n");
     printf("   -help:        this usage info...\n");
     printf("\n");
