@@ -1,5 +1,5 @@
 /*
-$Id: cmdline.h,v 1.30 2005/08/12 23:02:36 rasc Exp $
+$Id: cmdline.h,v 1.33 2006/03/06 00:04:54 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: cmdline.h,v 1.30 2005/08/12 23:02:36 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 
@@ -32,7 +32,7 @@ enum TIME_MODE    {NO_TIME, FULL_TIME, DELTA_TIME};
 
 typedef struct _OPTIONS {
   int         packet_mode;
-  int         packet_header_sync;	// Try to do a softsync of packet sync bytes
+  int         packet_header_sync;	// Try to do a softsync of packet sync bytes -- $$$ OBSOLETE!!!
   int         buffer_hexdump;		// 0/1: print hexdump prior to decoding
   int         printhex;			// hexdump mode
   int         printdecode;		// decode verbose mode
@@ -61,6 +61,7 @@ typedef struct _OPTIONS {
   int         ts_raw_mode;		// Read full TS in TS stream mode (if hardware supported)
   int         time_mode;		// time print mode
   char        *privateProviderStr;	// Private Provider ID str (usedef tables, descr)
+  int         dsmcc_save;		// save modules from DSM-CC to file
   int         hide_copyright;  		// suppress message at prog start
   int         help;
 } OPTION;
