@@ -1,5 +1,5 @@
 /*
-$Id: helper.c,v 1.37 2005/07/11 23:06:47 rasc Exp $
+$Id: helper.c,v 1.42 2006/01/02 18:24:04 rasc Exp $
 
 
  DVBSNOOP
@@ -7,12 +7,27 @@ $Id: helper.c,v 1.37 2005/07/11 23:06:47 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 
 
 $Log: helper.c,v $
+Revision 1.42  2006/01/02 18:24:04  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.41  2005/12/27 23:30:28  rasc
+PS MPEG-2 Extension data packets, MPEG-2 decoding
+
+Revision 1.40  2005/11/23 23:06:09  rasc
+ISO13818-2  MPEG2 sequence header
+
+Revision 1.39  2005/09/12 20:56:16  rasc
+Make dvbsnoop compile on Cygwin / Windows
+
+Revision 1.38  2005/09/02 14:11:35  rasc
+TS code redesign, xPCR and DTS timestamps decoding
+
 Revision 1.37  2005/07/11 23:06:47  rasc
 Multibyte section filter redesign:  -f 0x4F.22.33.44.55.66 -m 0x.FF.FF.FF etc.
 Manpage update
@@ -162,6 +177,7 @@ dvbsnoop v0.7  -- Commit to CVS
 #include <assert.h>
 
 
+#include "dvbsnoop.h"
 #include "helper.h"
 #include "hexprint.h"
 #include "output.h"
@@ -489,7 +505,7 @@ u_char *getISO639_3 (u_char *str, u_char *buf)
 {
   int i;
 
-  strncpy (str, buf, 3);
+  strncpy ((char *) str, (char *)buf, 3);
   *(str+3) = '\0';
 
   // secure print of string
@@ -505,6 +521,15 @@ u_char *getISO639_3 (u_char *str, u_char *buf)
 
 
 
+
+/*
+  -----------------------------------------------------------------------------------
+ */
+
+
+
+
+
 /*
   -- print_text_468A 
   -- ETSI EN 300 468  Annex A
@@ -672,23 +697,51 @@ void print_timebase90kHz (int v, long long time90kHz)
    long long ull = time90kHz;
 
    	int     h,m,s,u;
-	u_long  p = ull/90;
+	u_long  p = ull/9;
 
-	// -- following lines taken from "dvbtextsubs  Dave Chapman"
-	h=(p/(1000*60*60));
-	m=(p/(1000*60))-(h*60);
-	s=(p/1000)-(h*3600)-(m*60);
-	u=p-(h*1000*60*60)-(m*1000*60)-(s*1000);
+
+	// -- following lines basically taken from "dvbtextsubs  Dave Chapman"
+	h=(p/(10000L*60*60));
+	m=(p/(10000L*60))-(h*60);
+	s=(p/10000L)-(h*3600)-(m*60);
+	u=p-(h*10000L*60*60)-(m*10000L*60)-(s*10000L);
 
     	out (v,"%llu (0x%08llx)", ull,ull);
-	out (v,"  [= 90 kHz-Timestamp: %d:%02d:%02d.%03d]", h,m,s,u);
+	out (v,"  [= 90 kHz-Timestamp: %d:%02d:%02d.%04d]", h,m,s,u);
 }
 
 
+/*
+ -- print PCR timebase, 27 MHz
+*/ 
+
+void print_pcr_time (int v, long long time90kHz, int ext_27MHz)
+{
+   long long ull = time90kHz * 300 + ext_27MHz;
+
+   	int        h,m,s;
+	long       u;
+	long long  p = ull/27;
+	long long  fa = 1000000;
+
+	// -- following lines basically taken from "dvbtextsubs  Dave Chapman"
+	h=(p/(fa*60*60));
+	m=(p/(fa*60))-(h*60);
+	s=(p/fa)-(h*3600)-(m*60);
+	u=p-(h*fa*60*60)-(m*fa*60)-(s*fa);
+
+    	out (v,"%llu (0x%08llx)", ull,ull);
+	out (v,"  [= PCR-Timestamp: %d:%02d:%02d.%06ld]", h,m,s,u);
+}
+
+
+
+
+
+
 /*
   -- print data bytes (str + hexdump)
   -- print  "Private Data" and Hex-Dump
-
 */
 void print_databytes (int v, const char *str, u_char *b, u_int len)
 {
@@ -716,6 +769,51 @@ void print_databytes_line  (int v, const char *str, u_char *b, u_int len)
 
 
 
+/*
+  -- print Bit Matrix  x * y
+  -- print  Hex-Value and Bit-String  
+  -- Matrix may start at any bit position
+  -- x <= 64 bits !!
+*/
+void print_BitMatrix (int v, char *str, u_char *b, int bitoffset,  int matrix_x, int matrix_y)
+{
+  unsigned long long c;
+  int                i;
+
+
+  if (matrix_x <= 0 || matrix_y <= 0)  return;
+
+
+  out_nl (v,"%s (%d x %d)",str,matrix_x,matrix_y);
+  indent (1);
+  while (matrix_y-- > 0) {
+
+	if (matrix_x <= 32) {
+		c = outBit_Sx   (v, "", b, bitoffset , matrix_x);
+	} else {
+		c = outBit64_Sx (v, "", b, bitoffset , matrix_x);
+	}
+
+	out (v,"   [= ");
+        i = matrix_x;
+	while (--i >= 0) {
+		out (v, (c & 1<<i) ? "1" : "0");
+	}
+	out_nl (v,"]");
+
+	bitoffset += matrix_x;
+  }
+  indent (-1);
+
+}
+
+
+
+
+
+/*
+  -----------------------------------------------------------------------------------
+ */
 
 
 
@@ -843,6 +941,11 @@ static char *_str_cell_latitude_longitude (long ll, int angle)
 
 
 
+/*
+  -----------------------------------------------------------------------------------
+ */
+
+
 
 
 /*
@@ -909,6 +1012,11 @@ void displ_IPv6_addr (int v, struct IPv6ADDR *a)
 
 
 
+/*
+  -----------------------------------------------------------------------------------
+ */
+
+
 
 /*
  * --  return a bit string for value, len bits
