@@ -1,5 +1,5 @@
 /*
-$Id: print_header.c,v 1.4 2004/11/16 23:02:50 rasc Exp $
+$Id: print_header.c,v 1.7 2006/01/02 18:24:04 rasc Exp $
 
 
  DVBSNOOP
@@ -7,12 +7,24 @@ $Id: print_header.c,v 1.4 2004/11/16 23:02:50 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 
 
 $Log: print_header.c,v $
+Revision 1.7  2006/01/02 18:24:04  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.6  2005/10/20 22:25:07  rasc
+ - Bugfix: tssubdecode check for PUSI and SI pointer offset
+   still losing packets, when multiple sections in one TS packet.
+ - Changed: some Code rewrite
+ - Changed: obsolete option -nosync, do always packet sync
+
+Revision 1.5  2005/09/12 20:56:16  rasc
+Make dvbsnoop compile on Cygwin / Windows
+
 Revision 1.4  2004/11/16 23:02:50  rasc
 cmd option "-tsraw" for full/raw TS read (if supported by hard-/firmware)
 
@@ -47,7 +59,7 @@ some changes on packet header output
 
 
 
-void  print_packet_header (OPTION *opt, char *packetTyp, int pid, int count, int length, int skipped_bytes)
+void  print_packet_header (OPTION *opt, char *packetTyp, u_int pid, int count, int length)
 
 {
    char  str[50];
@@ -77,10 +89,10 @@ void  print_packet_header (OPTION *opt, char *packetTyp, int pid, int count, int
    	out_receive_time (1, opt);
    }
 
-   if (skipped_bytes) {
-       out_nl (1,"Syncing %s... (%ld bytes skipped)",
-		packetTyp,skipped_bytes);
-   }
+//   if (skipped_bytes) {
+//       out_nl (1,"Syncing %s... (%ld bytes skipped)",
+//		packetTyp,skipped_bytes);
+//   }
 
    out_nl (1,"------------------------------------------------------------");
 
