@@ -1,5 +1,5 @@
 /*
-$Id: pes_std.h,v 1.2 2004/02/02 23:34:08 rasc Exp $
+$Id: pes_std.h,v 1.4 2006/01/02 18:24:12 rasc Exp $
 
    
  DVBSNOOP
@@ -7,14 +7,14 @@ $Id: pes_std.h,v 1.2 2004/02/02 23:34:08 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
 
 */
 
-#ifndef __PES_STD_H
-#define __PES_STD_H 1
+#ifndef __PES_STD_H__
+#define __PES_STD_H__ 
 
 void  PES_decode_std (u_char *b, int len, u_int PES_streamID);
 
