@@ -1,5 +1,5 @@
 /*
-$Id: pespacket.c,v 1.27 2005/08/10 21:28:18 rasc Exp $
+$Id: pespacket.c,v 1.37 2006/01/02 18:24:12 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: pespacket.c,v 1.27 2005/08/10 21:28:18 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de  (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de  (rasc)
 
 
 
@@ -16,6 +16,41 @@ $Id: pespacket.c,v 1.27 2005/08/10 21:28:18 rasc Exp $
 
 
 $Log: pespacket.c,v $
+Revision 1.37  2006/01/02 18:24:12  rasc
+just update copyright and prepare for a new public tar ball
+
+Revision 1.36  2005/12/27 23:30:29  rasc
+PS MPEG-2 Extension data packets, MPEG-2 decoding
+
+Revision 1.35  2005/11/23 23:06:10  rasc
+ISO13818-2  MPEG2 sequence header
+
+Revision 1.34  2005/11/10 00:05:45  rasc
+ - New: PS MPEG2 UserData + GOP, DVB-S2 fix
+
+Revision 1.33  2005/11/08 23:15:25  rasc
+ - New: DVB-S2 Descriptor and DVB-S2 changes (tnx to Axel Katzur)
+ - Bugfix: PES packet stuffing
+ - New:  PS/PES read redesign and some code changes
+
+Revision 1.32  2005/10/20 22:25:07  rasc
+ - Bugfix: tssubdecode check for PUSI and SI pointer offset
+   still losing packets, when multiple sections in one TS packet.
+ - Changed: some Code rewrite
+ - Changed: obsolete option -nosync, do always packet sync
+
+Revision 1.31  2005/09/06 23:58:50  rasc
+typo fix
+
+Revision 1.30  2005/09/06 23:32:04  rasc
+no message
+
+Revision 1.29  2005/09/06 23:13:52  rasc
+catch OS signals (kill ...) for smooth program termination
+
+Revision 1.28  2005/09/02 14:11:35  rasc
+TS code redesign, xPCR and DTS timestamps decoding
+
 Revision 1.27  2005/08/10 21:28:18  rasc
 New: Program Stream handling  (-s ps)
 
@@ -123,78 +158,171 @@ dvbsnoop v0.7  -- Commit to CVS
 #include "pes_dsmcc.h"
 #include "pes_psm.h"
 #include "pes_psdir.h"
-#include "pes_misc.h"
+#include "mpeg_packheader.h"
+#include "mpeg_sysheader.h"
+#include "mpeg2_video.h"
+
 #include "strings/dvb_str.h"
 #include "misc/hexprint.h"
 #include "misc/output.h"
+#include "misc/print_header.h"
+#include "misc/cmdline.h"
 
 
 
+//
+// -- process PS PES packet (in sync) 
+// -- hexdump, decoding
+//
 
-
-void decodePS_buf (u_char *b, u_int len, int pid)
+void processPS_PES_packet (u_int pid, long pkt_nr, u_char *buf, int len)
 {
-   decodePS_buf (b, len, pid);
+	
+  OPTION *opt  = getOptionPtr();
+  char *strx   = (opt->packet_mode == PES) ? "PES" : "PS";
+
+
+       indent (0);
+       print_packet_header (opt, strx, opt->pid, pkt_nr, len);
+
+
+       if (opt->buffer_hexdump) {
+           printhex_buf (0, buf, len);
+           out_NL(0);
+       }
+
+
+       // decode protocol
+       if (opt->printdecode) {
+          decodePS_PES_packet (buf, len ,opt->pid);
+          out_nl (3,"==========================================================");
+          out_NL (3);
+       }
+
+
 }
 
 
 
 
-void decodePES_buf (u_char *b, u_int len, int pid)
+
+
+
+void decodePS_PES_packet (u_char *b, u_int len, int pid)
 {
  /* IS13818-1  2.4.3.6  */
 
- typedef struct  _PES_Packet {
-	u_long	  packet_start_code_prefix;		// 24 bit
-	u_int     stream_id;
-	u_int     PES_packet_length;
-
-	// N ... data
-
- } PES_Packet;
+  u_long    packet_start_code_prefix;		// 24 bit
+  u_int     stream_id;
+  u_int     PES_packet_length;
 
 
 
 
- PES_Packet   p;
-
-
 
  // -- Get/check packet header prefix (sync bits)
 
- p.packet_start_code_prefix		 = getBits (b, 0,  0, 24);
- if (p.packet_start_code_prefix != 0x000001) {
-      out_nl (3," !!! Packet_Start_CODE [%06lx] is wrong (= no PES/PS [0x000001])!!!\n",
-		p.packet_start_code_prefix);
-      // $$$    return;
+ packet_start_code_prefix		 = getBits (b, 0,  0, 24);
+ if (packet_start_code_prefix != 0x000001) {
+	out_nl (3," !!! Packet_Start_CODE [%06lx] is wrong (= no PES/PS [0x000001])!!!\n",
+		packet_start_code_prefix);
+	print_databytes (4,"Unknown packet data:", b, len);
+	return;
  }
- out_nl (3,"Packet_start_code_prefix: 0x%06lx",p.packet_start_code_prefix);
+ out_nl (3,"Packet_start_code_prefix: 0x%06lx",packet_start_code_prefix);
 
 
 
  // -- PS/PES stream ID
 
- p.stream_id = outBit_S2x_NL(3,"Stream_id: ",	b, 24, 8,
+ stream_id = outBit_S2x_NL(3,"Stream_id: ",	b, 24, 8,
 		 (char *(*)(u_long))dvbstrPESstream_ID );
 
 
 
 
+
    //
+   // -- PES Stream ID 0x00 - 0xB8
+   // -- ISO 13818-2
+   //
+
+   if (stream_id <= 0xB8) {
+
+   		// $$$ TODO  PES Stream ID 0x00 - 0xB8
+		//    reserved	B0
+		//    reserved	B1
+		//    sequence_error_code	B4  (not for streams)
+		//    reserved	B6
+
+	indent (+1);
+	switch (stream_id) {
+
+	  case 0x00:			// picture_start_code   00
+		MPEG2_decodePictureHeader (4, b, len);
+		break;
+
+	  case 0xB2:			// user_data_start_code B2
+		MPEG2_decodeUserData (4, b, len);
+		break;
+
+	  case 0xB3:			// sequence_header_code B3
+		MPEG2_decodeSequenceHeader (4, b, len);
+		break;
+
+	  case 0xB5:			// extension_data       B5
+		MPEG2_decodeExtension (4, b, len);
+		break;
+
+	  case 0xB7:			// sequence_end_code	B7
+		MPEG2_decodeSequenceEnd (4, b, len);
+		return;
+
+	  case 0xB8:			//    group_start_code	B8
+		MPEG2_decodeGroupOfPictures (4, b, len);
+		break;
+
+	  default:
+					//    slice_start_code	01 through AF
+		if (stream_id >= 0x01 && stream_id <= 0xAF) {
+
+			MPEG2_decodeSlice (4, b, len);
+
+		} else {
+					//    unkown
+		   if (len > 4) {		// sync + stream_id = 4 bytes
+			print_databytes (4,"MPEG2 Data (incl. sync + id):", b, len);
+		   }
+
+		}
+		break;
+	}
+	indent (-1);
+
+	return;
+
+   }
+
+
+
+
+
+   //
+   // -- PES Stream ID 0xB9 - 0xBB
    // -- check PS decoding (ProgramStream)
    //
 
-   switch (p.stream_id) {
+   switch (stream_id) {
 	case 0xB9:	// MPEG_program_end
 			// stream ID already printed, nothing else to do
 		return;
 
 	case 0xBA:	// MPEG_pack_header_start
-		pack_header (3, b, -1);		// startcode & ID already printed
+		mpeg_pack_header (3, b, -1);		// startcode & ID already printed
 		return;
 
 	case 0xBB:	// MPEG_system_header_start
-		system_header (3, b, -1);	// startcode & ID already printed
+		mpeg_system_header (3, b, -1);	// startcode & ID already printed
 		return;
    }
 
@@ -202,42 +330,33 @@ void decodePES_buf (u_char *b, u_int len, int pid)
 
 
 
+
    // 
    // -- PES decoding ...
+   // -- StreamID 0xBC..0xFF
    //
 
-
- p.PES_packet_length = outBit_Sx_NL (3,"PES_packet_length: ",	b,32, 16);
-
-
- b   += 6;
- len -= 6;
-
-
- switch (p.stream_id) {
-
-	// -- special ProgramStream (PS) - IDs
-	// $$$ TODO   (out of this control struct due to length handling, etc??)
-//	case 0xB9:		// MPEG_program_end
-//	case 0xBA:		// MPEG_pack_header_start
-//	case 0xBB:		// MPEG_system_header_start
+   PES_packet_length = outBit_Sx_NL (3,"PES_packet_length: ",	b,32, 16);
+   b   += 6;
+   len -= 6;
 
 
+   switch (stream_id) {
 
 	case 0xBC:		// program_stream_map
-		PES_decodePSM (b, p.PES_packet_length);
+		PES_decodePSM (b, PES_packet_length);
 		break;
 
 	case 0xBE:		// padding stream!
-		print_databytes (3,"Padding_bytes:", b, p.PES_packet_length);
+		print_databytes (3,"Padding_bytes:", b, PES_packet_length);
 		break;
 
 	case 0xF2:		// DSMCC stream
-		PES_decodeDSMCC (b, p.PES_packet_length);
+		PES_decodeDSMCC (b, PES_packet_length);
 		break;
 
 	case 0xFF:		// program_stream_directory
-		PES_decodePSDIR (b, p.PES_packet_length);
+		PES_decodePSDIR (b, PES_packet_length);
 		break;
 
 
@@ -245,7 +364,7 @@ void decodePES_buf (u_char *b, u_int len, int pid)
 	case 0xF0:		// ECM
 	case 0xF1:		// EMM
 	case 0xF8:		// ITU-T Rec. H.222.1 type E
-		print_databytes (3,"PES_packet_data_bytes:", b, p.PES_packet_length);
+		print_databytes (3,"PES_packet_data_bytes:", b, PES_packet_length);
 		break;
 
 	// case 0xFC:		// metadata stream	(see: H.222.0 AMD1)
@@ -266,25 +385,23 @@ void decodePES_buf (u_char *b, u_int len, int pid)
 	// case 0xFE		// reserved data stream
 	
 	default:
- 		if ((p.PES_packet_length==0) && ((p.stream_id & 0xF0)==0xE0)) {
+		{
+		   int xlen = PES_packet_length;
 
+ 		   if ((PES_packet_length==0) && ((stream_id & 0xF0)==0xE0)) {
 			 out_nl (3," ==> unbound video elementary stream... \n");
-			 if (len > 0)  {
-				indent (+1);
-				PES_decode_std (b, len, p.stream_id);
-				indent (-1);
-			 }
-
- 		} else {
-
+			 xlen = len;	// PES len field == 0, use read packet len
+ 		   }
+		   if (xlen > 0) {
 			indent (+1);
-			PES_decode_std (b, p.PES_packet_length, p.stream_id);
+			PES_decode_std (b, xlen, stream_id);
 			indent (-1);
+		   }
 
 		}
 		break;
 
- }
+   } // switch
 
 
 }
@@ -307,11 +424,9 @@ void decodePES_buf (u_char *b, u_int len, int pid)
 
 // Annotations: 
 //
-// $$$ TODO  0x000001B9    ISO 13818-1/H.222.0 2.5.3.1  End Program Stream ???
 //
 // $$$ TODO  0x00000100-B8 ISO 13818-2  Start codes
 //
 
 
 
-
