@@ -1,5 +1,5 @@
 /*
-$Id: dvb_descriptor_premiere.h,v 1.1 2004/11/03 21:01:02 rasc Exp $ 
+$Id: dvb_descriptor_premiere.h,v 1.3 2006/04/04 17:16:54 rasc Exp $ 
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: dvb_descriptor_premiere.h,v 1.1 2004/11/03 21:01:02 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de (rasc)
 
 
  -- private DVB Descriptors  Premiere.de
@@ -15,6 +15,12 @@ $Id: dvb_descriptor_premiere.h,v 1.1 2004/11/03 21:01:02 rasc Exp $
 
 
 $Log: dvb_descriptor_premiere.h,v $
+Revision 1.3  2006/04/04 17:16:54  rasc
+finally fix typo in premiere descriptor name
+
+Revision 1.2  2006/01/02 18:24:16  rasc
+just update copyright and prepare for a new public tar ball
+
 Revision 1.1  2004/11/03 21:01:02  rasc
  - New: "premiere.de" private tables and descriptors (tnx to Peter.Pavlov, Premiere)
  - New: cmd option "-privateprovider <provider name>"
@@ -31,7 +37,7 @@ Revision 1.1  2004/11/03 21:01:02  rasc
 
 void descriptor_PRIVATE_PremiereDE_ContentOrder (u_char *b);
 void descriptor_PRIVATE_PremiereDE_ParentalInformation (u_char *b);
-void descriptor_PRIVATE_PremiereDE_ContentTransmition (u_char *b);
+void descriptor_PRIVATE_PremiereDE_ContentTransmission (u_char *b);
 
 
 #endif
