@@ -1,5 +1,5 @@
 /*
-$Id: premiere_de.c,v 1.3 2005/08/10 21:28:19 rasc Exp $
+$Id: premiere_de.c,v 1.5 2006/04/04 17:16:54 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: premiere_de.c,v 1.3 2005/08/10 21:28:19 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de  (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de  (rasc)
 
 
   -- User defined table // Private
@@ -16,6 +16,12 @@ $Id: premiere_de.c,v 1.3 2005/08/10 21:28:19 rasc Exp $
 
 
 $Log: premiere_de.c,v $
+Revision 1.5  2006/04/04 17:16:54  rasc
+finally fix typo in premiere descriptor name
+
+Revision 1.4  2006/01/02 18:24:16  rasc
+just update copyright and prepare for a new public tar ball
+
 Revision 1.3  2005/08/10 21:28:19  rasc
 New: Program Stream handling  (-s ps)
 
@@ -57,7 +63,7 @@ Revision 1.1  2004/11/03 21:01:02  rasc
 static PRIV_DESCR_ID_FUNC pdescriptors[] = {
 	{ 0xF0, DVB_SI,   descriptor_PRIVATE_PremiereDE_ContentOrder },
 	{ 0xF1, DVB_SI,   descriptor_PRIVATE_PremiereDE_ParentalInformation },
-	{ 0xF2, DVB_SI,   descriptor_PRIVATE_PremiereDE_ContentTransmition },
+	{ 0xF2, DVB_SI,   descriptor_PRIVATE_PremiereDE_ContentTransmission },
 	{ 0x00,	0,        NULL } // end of table  (id = 0x00, funct = NULL)
 };
 
