@@ -1,5 +1,5 @@
 /*
-$Id: userdefs.c,v 1.2 2005/08/10 21:28:18 rasc Exp $
+$Id: userdefs.c,v 1.4 2005/12/29 02:43:38 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: userdefs.c,v 1.2 2005/08/10 21:28:18 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2005   Rainer.Scherg@gmx.de  (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de  (rasc)
 
 
   Private Sections & Descriptors
@@ -16,6 +16,12 @@ $Id: userdefs.c,v 1.2 2005/08/10 21:28:18 rasc Exp $
  
 
 $Log: userdefs.c,v $
+Revision 1.4  2005/12/29 02:43:38  rasc
+gcc fixes, man page update
+
+Revision 1.3  2005/12/22 16:21:51  rasc
+Update and new descriptors EN 300 468 v1.7.1
+
 Revision 1.2  2005/08/10 21:28:18  rasc
 New: Program Stream handling  (-s ps)
 
@@ -191,7 +197,7 @@ void descriptor_PRIVATE (u_char *b, DTAG_SCOPE tag_scope)
 // -- z.B. "premiere.de"
 //
 
-void set_PRIVATE_ProviderStr (u_char *s)
+void set_PRIVATE_ProviderStr (char *s)
 {
    int i = sizeof (privProviderStr)-1;
 
@@ -263,3 +269,12 @@ static void *get_tag_table_for_ProviderStr (int type)
 
 
 
+
+
+// $$$ TODO:  change interface mimic (call priv. data decoding):
+//       output if data matches for output
+//       return: true/false if data was decoded 
+//        exec should be done to any standard table/descriptor checking
+//        so we can overlay also standard descriptors/table (e.g. if change by provider)
+//        --> see descriptor enhancments for e.g. IDSB (ARIB STD-10, japanese)
+//
