@@ -1,5 +1,5 @@
 /*
-$Id: sectables.c,v 1.32 2005/07/31 21:48:03 rasc Exp $
+$Id: sectables.c,v 1.35 2005/12/29 02:43:39 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: sectables.c,v 1.32 2005/07/31 21:48:03 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de  (rasc)
+ (c) 2001-2006   Rainer.Scherg@gmx.de  (rasc)
 
 
  -- For more information please see: ISO 13818 (-1) and ETSI 300 468
@@ -15,6 +15,20 @@ $Id: sectables.c,v 1.32 2005/07/31 21:48:03 rasc Exp $
 
 
 $Log: sectables.c,v $
+Revision 1.35  2005/12/29 02:43:39  rasc
+gcc fixes, man page update
+
+Revision 1.34  2005/11/08 23:15:26  rasc
+ - New: DVB-S2 Descriptor and DVB-S2 changes (tnx to Axel Katzur)
+ - Bugfix: PES packet stuffing
+ - New:  PS/PES read redesign and some code changes
+
+Revision 1.33  2005/10/20 22:25:08  rasc
+ - Bugfix: tssubdecode check for PUSI and SI pointer offset
+   still losing packets, when multiple sections in one TS packet.
+ - Changed: some Code rewrite
+ - Changed: obsolete option -nosync, do always packet sync
+
 Revision 1.32  2005/07/31 21:48:03  rasc
 soft CRC for sections...
 
@@ -176,7 +190,7 @@ dvbsnoop v0.7  -- Commit to CVS
 #include "misc/hexprint.h"
 #include "misc/cmdline.h"
 #include "misc/crc32.h"
-
+#include "misc/print_header.h"
 
 
 
@@ -185,13 +199,46 @@ void  guess_table (u_char *buf, int len, u_int pid);
 
 
 
+//
+// -- process SI packet (Sections)
+// -- hexdump, decoding
+//
+
+void processSI_packet (u_int pid, long pkt_nr, u_char *buf, int len)
+{
+	
+  OPTION *opt  = getOptionPtr();
+
+
+       indent (0);
+       print_packet_header (opt, "SECT", opt->pid, pkt_nr, len);
+
+
+       if (opt->buffer_hexdump) {
+           printhex_buf (0,buf, len);
+           out_NL(0);
+       }
+
+
+       // -- decode protocol
+       if (opt->printdecode) {
+          decodeSI_packet (buf,len ,opt->pid);
+          out_nl (3,"==========================================================");
+          out_NL (3);
+       }
+
+}
+
+
+
+
 
 /* 
  -- decode Sections buffer by identifying the table IDs
  -- siehe EN 300 468 S.14 
 */
 
-void decodeSections_buf (u_char *buf, int len, u_int pid)
+void decodeSI_packet (u_char *buf, int len, u_int pid)
 
 {
   OPTION *opt;
@@ -210,6 +257,7 @@ void decodeSections_buf (u_char *buf, int len, u_int pid)
   	s =  dvbstrPID_assignment(pid);
 	if (*s) out (2,"  [= assigned for: %s]", s);
 	out_NL (2);
+	out_NL (2);
   }
 
 
@@ -221,7 +269,7 @@ void decodeSections_buf (u_char *buf, int len, u_int pid)
   softcrc_fail = 0;
 
   if (opt->soft_crc) {
-    u_long crc = crc32 (buf,len);
+    u_long crc = crc32 ((char *)buf,len);
     if (crc) {
 	softcrc_fail = 1;
     }
