@@ -1,5 +1,5 @@
 /*
-$Id: dsmcc_str.c,v 1.34 2004/07/25 20:12:59 rasc Exp $
+$Id: dsmcc_str.c,v 1.38 2006/03/06 20:25:38 rasc Exp $
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: dsmcc_str.c,v 1.34 2004/07/25 20:12:59 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de
+ (c) 2001-2006   Rainer.Scherg@gmx.de
 
 
  -- DSM-CC -Strings
@@ -15,6 +15,21 @@ $Id: dsmcc_str.c,v 1.34 2004/07/25 20:12:59 rasc Exp $
 
 
 $Log: dsmcc_str.c,v $
+Revision 1.38  2006/03/06 20:25:38  rasc
+DSM-CC Carousell, lots of Bugfixes, BIOP::Message not yet decodable (ddb has to collect Modules)
+
+Revision 1.37  2006/03/06 01:14:50  rasc
+Bugfixes... DSMCC BIOPs...
+
+Revision 1.36  2006/03/06 00:05:03  rasc
+More DSM-CC stuff: BIOP::FileMessage, BIOP::DirectoryMessage,
+BIOP::Stream::BIOP::StreamEvent, BIOP::ServiceGateway, DSM-TAPs, etc.
+this is a preparation for a patch sent in by Richard Case (DSMCC-Save).
+Attention: Code is still untested and may considered to be buggy (some teststreams are needed)...
+
+Revision 1.35  2006/01/02 18:24:32  rasc
+just update copyright and prepare for a new public tar ball
+
 Revision 1.34  2004/07/25 20:12:59  rasc
  - New: content_identifier_descriptor (TS 102 323)
  - New: TVA_id_descriptor (TS 102 323)
@@ -1016,7 +1031,7 @@ char *dsmccStrMHP_caching_transparency_level (u_int id)
 	{ 0x00, 0x00,   "reserved" },
 	{ 0x01, 0x01,   "transparent caching" },
 	{ 0x02, 0x02,   "semi-transparent caching" },
-	{ 0x03, 0x03,   "static chaching" },
+	{ 0x03, 0x03,   "static caching" },
 	{ 0x04, 0xFF,   "reserved" },
       	{  0,0, NULL }
   };
@@ -1123,12 +1138,49 @@ char *dsmccStr_transactionID_originator (u_int id)
 
 
 
+/*
+  -- DSM-CC  IOP ProfileID
+  -- ISO/IEC 13816-6
+  -- Profile Tags 0x49534F00 - 0x49534F0F (the first 3 octets spell ISO)
+  -- TR 101 202 
+  -- TS 102 812
+*/
+
+char *dsmccStrIOP_ProfileID (u_int id)
+{
+  STR_TABLE  TableIDs[] = {
+	{ 0x49534f00, 0x49534f00,   "TAG_MIN" },
+	{ 0x49534f01, 0x49534f01,   "TAG_CHILD" },
+	{ 0x49534f02, 0x49534f02,   "TAG_OPTIONS" },
+	{ 0x49534f03, 0x49534f03,   "TAG_LITE_MIN" },
+	{ 0x49534f04, 0x49534f04,   "TAG_LITE_CHILD" },
+	{ 0x49534f05, 0x49534f05,   "TAG_LITE_OPTIONS" },
+	{ 0x49534f06, 0x49534f06,   "TAG_BIOP" },
+	{ 0x49534f07, 0x49534f07,   "TAG_ONC" },
+	{ 0x49534f40, 0x49534f40,   "TAG_ConnBinder" },
+	{ 0x49534f41, 0x49534f41,   "TAG_IIOPAddr" },
+	{ 0x49534f42, 0x49534f42,   "TAG_Addr" },
+	{ 0x49534f43, 0x49534f43,   "TAG_NameId" },
+	{ 0x49534f44, 0x49534f44,   "TAG_IntfCode" },
+	{ 0x49534f45, 0x49534f45,   "TAG_ObjectKey" },
+	{ 0x49534f46, 0x49534f46,   "TAG_ServiceLocation" },
+	{ 0x49534f50, 0x49534f50,   "TAG_ObjectLocation" },
+	{ 0x49534f58, 0x49534f58,   "TAG_Intf" },
+      	{  0,0, NULL }
+  };
+
+  return findTableID (TableIDs, id);
+}
+
+
+
+
 /*
   -- DSM-CC  BIOP tap use
   -- ISO/IEC 13816-6
 */
 
-char *dsmccStrBIOP_TabUse (u_int id)
+char *dsmccStrBIOP_TAP_Use (u_int id)
 {
   STR_TABLE  TableIDs[] = {
 	{ 0x0000, 0x0000,   "UNKNOWN" },
@@ -1164,23 +1216,20 @@ char *dsmccStrBIOP_TabUse (u_int id)
 
 
 
+
+
 /*
-  -- DSM-CC  IOP ProfileID
+  -- BIOP/DSM::TAP  selector_type (MessageSelector)
   -- ISO/IEC 13816-6
-  -- Profile Tags 0x49534F00 - 0x49534F0F (the first 3 octets spell ISO)
+  -- ATSC A95, A47
 */
 
-char *dsmccStrIOP_ProfileID (u_int id)
+char *dsmccStrBIOP_TAP_SelectorType (u_int id)
 {
   STR_TABLE  TableIDs[] = {
-	{ 0x49534f00, 0x49534f00,   "TAG_MIN" },
-	{ 0x49534f01, 0x49534f01,   "TAG_CHILD" },
-	{ 0x49534f02, 0x49534f02,   "TAG_OPTIONS" },
-	{ 0x49534f03, 0x49534f03,   "TAG_LITE_MIN" },
-	{ 0x49534f04, 0x49534f04,   "TAG_LITE_CHILD" },
-	{ 0x49534f05, 0x49534f05,   "TAG_LITE_OPTIONS" },
-	{ 0x49534f06, 0x49534f06,   "TAG_BIOP" },
-	{ 0x49534f07, 0x49534f07,   "TAG_ONC" },
+	{ 0x0000, 0x0000,   "ISO/IEC reserved" },
+	{ 0x0001, 0x0001,   "MessageSelector" },
+	{ 0x0109, 0x0109,   "TSFS_Selector" },
       	{  0,0, NULL }
   };
 
@@ -1188,17 +1237,87 @@ char *dsmccStrIOP_ProfileID (u_int id)
 }
 
 
-// $$$ TODO
-// IOP::component_IDs
-//	{ 0x49534f40, 0x49534f40,   "TAG_ConnBinder" },
-//	{ 0x49534f41, 0x49534f41,   "TAG_IIOPAddr" },
-//	{ 0x49534f42, 0x49534f42,   "TAG_Addr" },
-//	{ 0x49534f43, 0x49534f43,   "TAG_NameId" },
-//	{ 0x49534f44, 0x49534f44,   "TAG_IntfCode" },
-//	{ 0x49534f45, 0x49534f45,   "TAG_ObjectKey" },
-//	{ 0x49534f46, 0x49534f46,   "TAG_ServiceLocation" },
-//	{ 0x49534f50, 0x49534f50,   "TAG_ObjectLocation" },
-//	{ 0x49534f58, 0x49534f58,   "TAG_Intf" },
+
+/*
+  -- BIOP/DSM::TAP  selector_type (MessageSelector)
+  -- ISO/IEC 13816-6
+  -- ATSC A95, A47
+*/
+
+char *dsmccStrBIOP_EndianType (u_int id)
+{
+  STR_TABLE  TableIDs[] = {
+	{ 0x00, 0x00,   "Big Endian" },
+	{ 0x01, 0xFF,   "Little Endian" },
+      	{  0,0, NULL }
+  };
+
+  return findTableID (TableIDs, id);
+}
+
+
+
+
+/*
+  -- BIOP   ObjectKind  / TypeID Aliases
+  -- ISO/IEC 13816-6
+*/
+
+char *dsmccStrBIOP_TypeID_Alias (u_int id)
+{
+  STR_TABLE  TableIDs[] = {
+	{ 0x64697200, 0x64697200,   "dir (DSM::Directory)" },
+	{ 0x66696c00, 0x66696c00,   "fil (DSM::File)" },
+	{ 0x73726700, 0x73726700,   "srg (DSM::ServiceGateway)" },
+	{ 0x73746500, 0x73746500,   "ste (DSM::StreamEvent)" },
+	{ 0x73747200, 0x73747200,   "str (BIOP::Stream)" },
+      	{  0,0, NULL }
+  };
+
+  return findTableID (TableIDs, id);
+}
+
+
+
+
+
+/*
+  -- BIOP   BindingType 
+  -- e.g. TS 102 812
+*/
+
+char *dsmccStrBIOP_BindingType (u_int id)
+{
+  STR_TABLE  TableIDs[] = {
+	{ 0x01, 0x01,   "nobject" },
+	{ 0x02, 0x02,   "ncontext" },
+      	{  0,0, NULL }
+  };
+
+  return findTableID (TableIDs, id);
+}
+
+
+
+
+/*
+  -- BIOP  "Magic"  ID 
+  -- e.g. TS 102 812
+*/
+
+char *dsmccStrBIOP_MAGIC (u_int id)
+{
+  STR_TABLE  TableIDs[] = {
+	{ 0x42494F50, 0x42494F50,   "BIOP" },
+      	{  0,0, NULL }
+  };
+
+  return findTableID (TableIDs, id);
+}
+
+
+
+
 
 
 
