@@ -1,5 +1,5 @@
 /*
-$Id: strtable_misc.h,v 1.1 2004/07/24 11:47:08 rasc Exp $ 
+$Id: strtable_misc.h,v 1.2 2005/12/27 23:30:30 rasc Exp $ 
 
 
  DVBSNOOP
@@ -7,7 +7,7 @@ $Id: strtable_misc.h,v 1.1 2004/07/24 11:47:08 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de
+ (c) 2001-2006   Rainer.Scherg@gmx.de
 
 
 
@@ -23,9 +23,9 @@ $Id: strtable_misc.h,v 1.1 2004/07/24 11:47:08 rasc Exp $
 
 
 typedef struct _STR_TABLE {
-    u_int    from;          /* e.g. from id 1  */
-    u_int    to;            /*      to   id 3  */
-    u_char   *str;          /*      is   string xxx */
+    u_int       from;          /* e.g. from id 1  */
+    u_int       to;            /*      to   id 3  */
+    const char  *str;          /*      is   string xxx */
 } STR_TABLE;
 
 
