@@ -1,5 +1,5 @@
 /*
-$Id: ts2secpes.h,v 1.3 2004/04/18 19:30:32 rasc Exp $
+$Id: ts2secpes.h,v 1.8 2006/01/02 18:24:34 rasc Exp $
 
 
    
@@ -8,7 +8,7 @@ $Id: ts2secpes.h,v 1.3 2004/04/18 19:30:32 rasc Exp $
  a dvb sniffer  and mpeg2 stream analyzer tool
  http://dvbsnoop.sourceforge.net/
 
- (c) 2001-2004   Rainer.Scherg@gmx.de
+ (c) 2001-2006   Rainer.Scherg@gmx.de
 
 
 */
@@ -25,7 +25,11 @@ int  ts2SecPes_AddPacketContinue (int pid, int cc, u_char *b, u_int len);
 
 void ts2SecPes_subdecode (u_char *b, int len, u_int pid);
 int  ts2SecPes_checkAndDo_PacketSubdecode_Output (void);
-void ts2SecPes_Output_subdecode (void);
+int  ts2SecPes_LastPacketReadSubdecode_Output (void);
+void ts2SecPes_Output_subdecode (u_int overleap_bytes);
+
+void  ts2sec_multipacket (u_char *b, int len, u_int pid);
+void  ts2ps_pes_multipacket (u_char *b, int len, u_int pid);
 
 
 
